package org.eclipse.smila.sample.pipelet

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.eclipse.eilf.blackboard.BlackboardService;
import org.eclipse.eilf.blackboard.path.Path;
import org.eclipse.eilf.datamodel.id.Id;
import org.eclipse.eilf.datamodel.record.Literal;
import org.eclipse.eilf.datamodel.record.RecordFactory;
import org.eclipse.eilf.processing.ProcessingException;
import org.eclipse.eilf.processing.SimplePipelet;
import org.eclipse.eilf.processing.configuration.PipeletConfiguration;

public class HelloWorldPipelet implements SimplePipelet {

  private final String PROP_IN_ATT_NAME = "IN_ATT_NAME";

  private final String PROP_OUT_ATT_NAME = "OUT_ATT_NAME";

  private String _inAttName;

  private String _outAttName;

  private final Log _log = LogFactory.getLog(HelloWorldPipelet.class);

  public HelloWorldPipelet() {
  }

  public void configure(PipeletConfiguration configuration) throws ProcessingException {
    _inAttName = (String) configuration.getPropertyFirstValueNotNull(PROP_IN_ATT_NAME);
    if (_inAttName.trim().length() == 0) {
      throw new ProcessingException("Property " + PROP_IN_ATT_NAME + " must not be an empty String");
    }

    _outAttName = (String) configuration.getPropertyFirstValueNotNull(PROP_OUT_ATT_NAME);
    if (_outAttName.trim().length() == 0) {
      throw new ProcessingException("Property " + PROP_OUT_ATT_NAME + " must not be an empty String");
    }

  }

  public Id[] process(BlackboardService blackboard, Id[] recordIds) throws ProcessingException {
    for (Id id : recordIds) {
      try {
        String inputValue = "";
        final Path path = new Path(_inAttName);
        if (blackboard.hasAttribute(id, path)) {
          inputValue = blackboard.getLiteral(id, path).getStringValue();
        }

        String outputValue = inputValue + " modified by HelloWorldPipelet";

        final Literal literal = RecordFactory.DEFAULT_INSTANCE.createLiteral();
        literal.setStringValue(outputValue);
        blackboard.setLiteral(id, new Path(_outAttName), literal);

      } catch (final Exception ex) {
        if (_log.isErrorEnabled()) {
          _log.error("error during execution of HelloWorldPipelet with record " + id, ex);
        }
      }
    } // for

    return recordIds;
  }
}
